Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PubSub ¶
type PubSub interface {
PublishTaskInstanceToRun(cxt context.Context, ti *core.TaskInstance, dag *core.DAG)
GetReadyToRunTasks(ctx context.Context, num int) ([]*core.TaskInstance, []interface{})
GetCompletedTasks(ctx context.Context, count int) ([]*core.TaskInstance, []interface{})
CreateConsumerGroupTasks(ctx context.Context)
CreateConsumerGroupTasksCompleted(ctx context.Context)
// AckTaskProcessed & AckTaskCompletionProcessed might be used by some
// brokers, might not be used by some.
AckTaskProcessed(ctx context.Context, taskID interface{})
AckTaskCompletionProcessed(ctx context.Context, id interface{})
PublishTaskInstanceAsComplete(cxt context.Context, ti *core.TaskInstance, dag *core.DAG)
}
PubSub is the common interface which should be implemented to interact for pub sub in different data stores, eg: redis, kafka. NOTE: They should be threadsafe to use.
func PubSubClient ¶
func PubSubClient() PubSub
Click to show internal directories.
Click to hide internal directories.